package com.yiqi.core.mapper;

import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.yiqi.core.domain.ClothHangerDetail;
import com.yiqi.core.domain.vo.ClothHangerDetailVO;
import com.yiqi.core.domain.vo.ClothHangerOrderRelationVO;
import com.yiqi.order.domain.OrderClothItem;
import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Param;
import org.springframework.web.bind.annotation.RequestParam;

import java.util.List;

/**
 * 挂架位置详情Mapper接口
 *
 * @author ruoyi
 * @date 2023-10-06
 */
public interface ClothHangerDetailMapper extends BaseMapper<ClothHangerDetail> {
    /**
     * 查询挂架位置详情
     *
     * @param id 挂架位置详情主键
     * @return 挂架位置详情
     */
    public ClothHangerDetail selectClothHangerDetailById(Long id);

    /**
     * 查询挂架位置详情列表
     *
     * @param clothHangerDetail 挂架位置详情
     * @return 挂架位置详情集合
     */
    public List<ClothHangerDetail> selectClothHangerDetailList(ClothHangerDetail clothHangerDetail);

    /**
     * 查询挂架位置详情列表
     *
     * @param hangerId 挂架位置详情
     * @return 挂架位置详情集合
     */
    public List<ClothHangerDetailVO> getIsHangerList(Long hangerId);

    /**
     * 新增挂架位置详情
     *
     * @param clothHangerDetail 挂架位置详情
     * @return 结果
     */
    public int insertClothHangerDetail(ClothHangerDetail clothHangerDetail);

    /**
     * 修改挂架位置详情
     *
     * @param clothHangerDetail 挂架位置详情
     * @return 结果
     */
    public int updateClothHangerDetail(ClothHangerDetail clothHangerDetail);

    /**
     * 删除挂架位置详情
     *
     * @param id 挂架位置详情主键
     * @return 结果
     */
    public int deleteClothHangerDetailById(Long id);

    /**
     * 批量删除挂架位置详情
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteClothHangerDetailByIds(Long[] ids);


    /**
     * 获取挂架位置已经上架的订单衣物详细信息
     *
     * @param hangerId 挂架id
     * @param hangerCode 挂架位置code
     * @return 结果
     */
    public List<ClothHangerOrderRelationVO> getClothOrderInfoByHangerCodeAndId(@Param("hangerId") Long hangerId, @Param("hangerCode") String hangerCode);
}
